@@ -1,6 +1,6 @@
-;;; Alegreya.el --- AUCTeX style for `Alegreya.sty' (v2015/10/22)
+;;; Alegreya.el --- AUCTeX style for `Alegreya.sty' (v2015/10/22)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2015, 2018 Free Software Foundation, Inc.
+;; Copyright (C) 2015, 2018, 2020 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -31,10 +31,13 @@
 
 ;;; Code:
 
+(require 'tex)
+(require 'latex)
+
 ;; Silence the compiler:
 (declare-function font-latex-add-keywords
-		  "font-latex"
-		  (keywords class))
+                  "font-latex"
+                  (keywords class))
 
 (TeX-add-style-hook
  "Alegreya"
@@ -45,7 +48,7 @@
 
    ;; Load `fontaxes' or `fontspec' dep. on `type1' option:
    (if (or (LaTeX-provided-package-options-member "Alegreya" "type1")
-	   (LaTeX-provided-package-options-member "Alegreya" "type1=true"))
+           (LaTeX-provided-package-options-member "Alegreya" "type1=true"))
        (TeX-run-style-hooks "fontaxes")
      (TeX-run-style-hooks "fontspec"))
 
@@ -66,20 +69,20 @@
 
    ;; Fontification
    (when (and (featurep 'font-latex)
-	      (eq TeX-install-font-lock 'font-latex-setup))
+              (eq TeX-install-font-lock 'font-latex-setup))
      (font-latex-add-keywords '(("textsu"    "{")
-				("textin"    "{"))
-			      'type-command)
+                                ("textin"    "{"))
+                              'type-command)
      (font-latex-add-keywords '(("Alegreya"      "")
-				("AlegreyaBlack" "")
-				("AlegreyaLF"    "")
-				("AlegreyaOsF"   "")
-				("AlegreyaTLF"   "")
-				("AlegreyaTOsF"  "")
-				("sufigures"     "")
-				("infigures"     ""))
-			      'type-declaration)))
- LaTeX-dialect)
+                                ("AlegreyaBlack" "")
+                                ("AlegreyaLF"    "")
+                                ("AlegreyaOsF"   "")
+                                ("AlegreyaTLF"   "")
+                                ("AlegreyaTOsF"  "")
+                                ("sufigures"     "")
+                                ("infigures"     ""))
+                              'type-declaration)))
+ TeX-dialect)
 
 (defvar LaTeX-Alegreya-package-options-list
   '(("lining"       ("true" "false"))
