@@ -1,6 +1,6 @@
-;;; beamerarticle.el --- AUCTeX style for the latex-beamerarticle class
+;;; beamerarticle.el --- AUCTeX style for the latex-beamerarticle class  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2019 Free Software Foundation, Inc.
+;; Copyright (C) 2019, 2020 Free Software Foundation, Inc.
 
 ;; Keywords: tex
 
@@ -27,6 +27,8 @@
 
 ;;; Code:
 
+(require 'tex)
+
 (TeX-add-style-hook
  "beamerarticle"
  (lambda ()
