@@ -1,7 +1,15 @@
-;;; danish.el --- Setup AUCTeX for editing Danish text.
+;;; danish.el --- Setup AUCTeX for editing Danish text.  -*- lexical-binding: t; -*-
 
 ;;; Code:
 
+(require 'tex)
+(require 'latex)
+
+;; Silence the compiler:
+(declare-function font-latex-add-quotes
+                  "font-latex"
+                  (quotes))
+
 (TeX-add-style-hook
  "danish"
  (lambda ()
@@ -12,6 +20,7 @@
    (when (fboundp 'font-latex-add-quotes)
      (font-latex-add-quotes '("\"`" "\"'"))
      (font-latex-add-quotes '("\">" "\"<" german)))
-   (run-hooks 'TeX-language-dk-hook)))
+   (run-hooks 'TeX-language-dk-hook))
+ TeX-dialect)
 
 ;;; danish.el ends here
