@@ -1,6 +1,6 @@
-;;; erewhon.el --- AUCTeX style for `erewhon.sty' (v1.04)
+;;; erewhon.el --- AUCTeX style for `erewhon.sty' (v1.04)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2014, 2015, 2018 Free Software Foundation, Inc.
+;; Copyright (C) 2014, 2015, 2018, 2020 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -31,10 +31,12 @@
 
 ;;; Code:
 
+(require 'tex)
+
 ;; Silence the compiler:
 (declare-function font-latex-add-keywords
-		  "font-latex"
-		  (keywords class))
+                  "font-latex"
+                  (keywords class))
 
 (TeX-add-style-hook
  "erewhon"
@@ -68,25 +70,25 @@
 
    ;; Fontification
    (when (and (featurep 'font-latex)
-	      (eq TeX-install-font-lock 'font-latex-setup))
+              (eq TeX-install-font-lock 'font-latex-setup))
      (font-latex-add-keywords '(("textlf"    "{")
-				("texttlf"   "{")
-				("textosf"   "{")
-				("texttosf"  "{")
-				("textsu"    "{")
-				("textin"    "{")
-				("textnu"    "{")
-				("textde"    "{"))
-			      'type-command)
+                                ("texttlf"   "{")
+                                ("textosf"   "{")
+                                ("texttosf"  "{")
+                                ("textsu"    "{")
+                                ("textin"    "{")
+                                ("textnu"    "{")
+                                ("textde"    "{"))
+                              'type-command)
      (font-latex-add-keywords '(("lfstyle"   "")
-				("tlfstyle"  "")
-				("osfstyle"  "")
-				("tosfstyle" "")
-				("sufigures" ""))
-			      'type-declaration)
+                                ("tlfstyle"  "")
+                                ("osfstyle"  "")
+                                ("tosfstyle" "")
+                                ("sufigures" ""))
+                              'type-declaration)
      (font-latex-add-keywords '(("textfrac"  "{{"))
-			      'textual)))
- LaTeX-dialect)
+                              'textual)))
+ TeX-dialect)
 
 (defvar LaTeX-erewhon-package-options
   '("lining" "lf" "oldstyle" "osf" "tabular" "p" "proportional"
