@@ -1,6 +1,6 @@
-;;; expl3.el --- AUCTeX style for `expl3.sty'
+;;; expl3.el --- AUCTeX style for `expl3.sty'  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2015, 2017-2019 Free Software Foundation, Inc.
+;; Copyright (C) 2015, 2017-2020 Free Software Foundation, Inc.
 
 ;; Author: Tassilo Horn <tsdh@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -30,10 +30,8 @@
 
 ;;; Code:
 
-;; Silence the compiler:
-(declare-function font-latex-update-font-lock
-		  "font-latex"
-		  (&optional syntactic-kws))
+(require 'tex)
+(require 'latex)
 
 (defvar font-latex-match-simple-include-list)
 
@@ -48,21 +46,18 @@
  "expl3"
  (lambda ()
    (set-syntax-table LaTeX-expl3-syntax-table)
-   (when (and (fboundp 'font-latex-update-font-lock)
-	      (eq TeX-install-font-lock 'font-latex-setup))
+   (when (and (eq TeX-install-font-lock 'font-latex-setup))
      ;; Fontify _ and : as part of macros.
      (add-to-list 'font-latex-match-simple-include-list "_" t)
-     (add-to-list 'font-latex-match-simple-include-list ":" t)
-     ;; Tell font-lock about the update.
-     (font-latex-update-font-lock t)))
- LaTeX-dialect)
+     (add-to-list 'font-latex-match-simple-include-list ":" t)))
+ TeX-dialect)
 
 (defun LaTeX-expl3-package-options ()
   "Read the expl3 package options from the user."
   (TeX-read-key-val t '(("check-declarations" ("true" "false"))
-			("log-functions" ("true" "false"))
-			("driver" ("auto"    "latex2e"
-				   "dvips"   "dvipdfmx"
-				   "pdfmode" "xdvipdfmx")))))
+                        ("log-functions" ("true" "false"))
+                        ("driver" ("auto"    "latex2e"
+                                   "dvips"   "dvipdfmx"
+                                   "pdfmode" "xdvipdfmx")))))
 
 ;;; expl3.el ends here
