@@ -1,6 +1,6 @@
-;;; gloss-italian.el --- Italian support for polyglossia package.
+;;; gloss-italian.el --- Italian support for polyglossia package.  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2015, 2018 Free Software Foundation, Inc.
+;; Copyright (C) 2015, 2018, 2020 Free Software Foundation, Inc.
 
 ;; Maintainer: auctex-devel@gnu.org
 ;; Author: Mosè Giordano <mose@gnu.org>
@@ -29,13 +29,16 @@
 
 ;;; Code:
 
+(require 'tex)
+(require 'latex)
+
 ;; Silence the compiler:
 (declare-function font-latex-add-quotes
-		  "font-latex"
-		  (quotes))
+                  "font-latex"
+                  (quotes))
 
 (declare-function LaTeX-polyglossia-lang-option-member
-		  "polyglossia" (language option))
+                  "polyglossia" (language option))
 
 (defvar TeX-language-it-hook nil
   "Hook run for Italian texts.")
@@ -50,24 +53,24 @@
       LaTeX-env-args [TeX-arg-key-val LaTeX-polyglossia-italian-options-list]))
 
    (when (or (LaTeX-polyglossia-lang-option-member "italian" "babelshorthands=true")
-	     (LaTeX-polyglossia-lang-option-member "italian" "babelshorthands"))
+             (LaTeX-polyglossia-lang-option-member "italian" "babelshorthands"))
      (unless (eq (car TeX-quote-language) 'override)
        (let ((open-quote (if (and (boundp 'LaTeX-italian-open-quote)
-				  LaTeX-italian-open-quote)
-			     LaTeX-italian-open-quote
-			   "\"<"))
-	     (close-quote (if (and (boundp 'LaTeX-italian-close-quote)
-				   LaTeX-italian-close-quote)
-			      LaTeX-italian-close-quote
-			    "\">")))
-	 (setq TeX-quote-language
-	       `("italian" ,open-quote ,close-quote ,TeX-quote-after-quote))))
+                                  LaTeX-italian-open-quote)
+                             LaTeX-italian-open-quote
+                           "\"<"))
+             (close-quote (if (and (boundp 'LaTeX-italian-close-quote)
+                                   LaTeX-italian-close-quote)
+                              LaTeX-italian-close-quote
+                            "\">")))
+         (setq TeX-quote-language
+               `("italian" ,open-quote ,close-quote ,TeX-quote-after-quote))))
 
      ;; Fontification of quotation marks.
      (when (fboundp 'font-latex-add-quotes)
        (font-latex-add-quotes '("\"<" "\">" french))))
    (run-hooks 'TeX-language-it-hook))
- LaTeX-dialect)
+ TeX-dialect)
 
 (defvar LaTeX-polyglossia-italian-options-list
   '(("babelshorthands" ("true" "false")))
