@@ -1,6 +1,6 @@
-;;; minted.el --- AUCTeX style for `minted.sty' (v2.5)
+;;; minted.el --- AUCTeX style for `minted.sty' (v2.5)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2014-2018 Free Software Foundation, Inc.
+;; Copyright (C) 2014-2021 Free Software Foundation, Inc.
 
 ;; Author: Tassilo Horn <tsdh@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -31,20 +31,20 @@
 ;;; Code:
 
 (require 'tex)
+(require 'latex)
 
 ;; Silence the compiler:
 (declare-function font-latex-add-keywords
-		  "font-latex"
-		  (keywords class))
+                  "font-latex"
+                  (keywords class))
 
-(declare-function font-latex-update-font-lock
-		  "font-latex"
-		  (&optional syntactic-kws))
+(declare-function font-latex-set-syntactic-keywords
+                  "font-latex")
 
 (declare-function LaTeX-color-definecolor-list "color" ())
 (declare-function LaTeX-xcolor-definecolor-list "xcolor" ())
 (declare-function LaTeX-add-newfloat-DeclareFloatingEnvironments
-		  "newfloat" (&rest newfloat-declarefloatingenvironments))
+                  "newfloat" (&rest newfloat-declarefloatingenvironments))
 
 (defvar font-latex-syntactic-keywords-extra)
 
@@ -94,8 +94,8 @@
     ("fontfamily" ("tt" "courier" "helvetica"))
     ("fontseries" ("auto"))
     ("fontsize" ("auto" "\\tiny" "\\large" "\\scriptsize" "\\Large"
-		 "\\footnotesize" "\\LARGE" "\\small" "\\huge"
-		 "\\normalsize" "\\Huge"))
+                 "\\footnotesize" "\\LARGE" "\\small" "\\huge"
+                 "\\normalsize" "\\Huge"))
     ("fontshape" ("auto"))
     ("formatcom")
     ("frame" ("none" "leftline" "topline" "bottomline" "lines" "single"))
@@ -132,11 +132,15 @@
     ;; in a .tex file, Emacs asks to apply a variable which is not
     ;; safe and does not restore the frame; the splitted frame
     ;; remains.  I couldn't figure out why, so for now, I add the
-    ;; styles from Pygments version 2.1.3 here.
-    ("style" ("colorful" "default" "emacs" "friendly" "fruity" "igor"
-	      "lovelace" "manni" "monokai" "murphy" "native"
-	      "paraiso-dark" "paraiso-light" "pastie" "perldoc"
-	      "rrt" "tango" "trac" "vim" "vs" "xcode"))
+    ;; styles from Pygments version 2.9 here.
+    ("style" ("abap" "algol" "algol_nu" "arduino" "autumn"
+              "borland" "bw" "colorful" "default" "emacs"
+              "friendly" "fruity" "gruvbox-dark" "gruvbox-light"
+              "igor" "inkpot" "lovelace" "manni" "material" "monokai"
+              "murphy" "native" "paraiso-dark" "paraiso-light"
+              "pastie" "perldoc" "rainbow_dash" "rrt" "sas"
+              "solarized-dark" "solarized-light" "stata" "stata-dark"
+              "stata-light" "tango" "trac" "vim" "vs" "xcode" "zenburn"))
     ("stepnumber")
     ("stepnumberfromfirst")
     ("stepnumberoffsetvalues" ("true" "false"))
@@ -151,9 +155,23 @@
     ("xrightmargin"))
   "Key=value options for minted macros and environments.")
 
-(defvar LaTeX-minted-key-val-options-local nil
-  "Buffer-local key=value options for minted macros and environments.")
-(make-variable-buffer-local 'LaTeX-minted-key-val-options-local)
+(defun LaTeX-minted-key-val-options ()
+  "Return an updated list of key=vals from minted package.
+This function retrieves values of (user) defined colors and
+prepends them to variable `LaTeX-minted-key-val-options'."
+  (append
+   (when (or (member "xcolor" (TeX-style-list))
+             (member "color" TeX-active-styles))
+     (let* ((colorcmd (if (member "xcolor" TeX-active-styles)
+                          #'LaTeX-xcolor-definecolor-list
+                        #'LaTeX-color-definecolor-list))
+            (colors (mapcar #'car (funcall colorcmd)))
+            (keys '("bgcolor" "highlightcolor"
+                    "rulecolor" "spacecolor" "tabcolor"))
+            result)
+       (dolist (key keys result)
+         (push (list key colors) result))))
+   LaTeX-minted-key-val-options))
 
 (defvar LaTeX-minted-pygmentize-program (executable-find "pygmentize"))
 
@@ -165,16 +183,16 @@
 Update the variable `LaTeX-minted-language-list' if still nil."
   (or LaTeX-minted-language-list
       (when LaTeX-minted-pygmentize-program
-	(with-temp-buffer
-	  (shell-command (concat LaTeX-minted-pygmentize-program " -L lexers")
-			 (current-buffer))
-	  (goto-char (point-min))
-	  (let (languages)
-	    (while (re-search-forward "^\\*[[:space:]]\\([^:]+\\):" nil t)
-	      (dolist (lang (split-string (match-string 1) "[[:space:],]" t))
-		(push lang languages)))
-	    (setq LaTeX-minted-language-list languages))
-	  LaTeX-minted-language-list))))
+        (with-temp-buffer
+          (shell-command (concat LaTeX-minted-pygmentize-program " -L lexers")
+                         (current-buffer))
+          (goto-char (point-min))
+          (let (languages)
+            (while (re-search-forward "^\\*[[:space:]]\\([^:]+\\):" nil t)
+              (dolist (lang (split-string (match-string 1) "[[:space:],]" t))
+                (push lang languages)))
+            (setq LaTeX-minted-language-list languages))
+          LaTeX-minted-language-list))))
 
 (defun LaTeX-arg-minted-language (optional &optional prompt)
     "Insert a selected pygmentize language as argument for macros from minted.sty.
@@ -182,7 +200,7 @@ If OPTIONAL is non-nil, insert it as optional argument in
 brackets.  PROMPT replaces the standard one."
   (TeX-argument-insert
    (completing-read (TeX-argument-prompt optional prompt "Language")
-		    (LaTeX-minted-language-list))
+                    (LaTeX-minted-language-list))
    optional))
 
 (defvar LaTeX-minted-style-list nil
@@ -193,16 +211,16 @@ brackets.  PROMPT replaces the standard one."
 Update the variable `LaTeX-minted-style-list' if still nil."
   (or LaTeX-minted-style-list
       (when LaTeX-minted-pygmentize-program
-	(with-temp-buffer
-	  (shell-command (concat LaTeX-minted-pygmentize-program " -L styles")
-			 (current-buffer))
-	  (goto-char (point-min))
-	  (let (styles)
-	    (while (re-search-forward "^\\*[[:space:]]\\([^:]+\\):" nil t)
-	      (dolist (style (split-string (match-string 1) "[[:space:],]" t))
-		(push style styles)))
-	    (setq LaTeX-minted-style-list styles))
-	  LaTeX-minted-style-list))))
+        (with-temp-buffer
+          (shell-command (concat LaTeX-minted-pygmentize-program " -L styles")
+                         (current-buffer))
+          (goto-char (point-min))
+          (let (styles)
+            (while (re-search-forward "^\\*[[:space:]]\\([^:]+\\):" nil t)
+              (dolist (style (split-string (match-string 1) "[[:space:],]" t))
+                (push style styles)))
+            (setq LaTeX-minted-style-list styles))
+          LaTeX-minted-style-list))))
 
 (defun LaTeX-arg-minted-style (optional &optional prompt)
   "Insert a selected pygmentize style as argument for macros from minted.sty.
@@ -210,30 +228,9 @@ If OPTIONAL is non-nil, insert it as optional argument in
 brackets.  PROMPT replaces the standard one."
   (TeX-argument-insert
    (completing-read (TeX-argument-prompt optional prompt "Style")
-		    (LaTeX-minted-style-list))
+                    (LaTeX-minted-style-list))
    optional))
 
-(defun LaTeX-minted-update-key-vals ()
-  "Update color related key-vals in `LaTeX-minted-key-val-options-local'.
-This function checks if one of the packages \"xcolor.sty\" or
-\"xcolor.sty\" is loaded and appends defined colors as values to
-color related key.  \"xcolor.sty\" is preferred if both packages
-are loaded."
-  (when (or (member "xcolor" (TeX-style-list))
-	    (member "color" (TeX-style-list)))
-    (let* ((colorcmd (if (member "xcolor" (TeX-style-list))
-			 #'LaTeX-xcolor-definecolor-list
-		       #'LaTeX-color-definecolor-list))
-	   (colorkeys '("bgcolor" "highlightcolor"
-			"rulecolor" "spacecolor" "tabcolor"))
-	   (opts (copy-alist LaTeX-minted-key-val-options-local)))
-      (dolist (key colorkeys)
-	(setq opts (assq-delete-all (car (assoc key opts)) opts))
-	(push (list key (mapcar #'car (funcall colorcmd)))
-	      opts))
-      (setq LaTeX-minted-key-val-options-local
-	    (copy-alist opts)))))
-
 (defvar LaTeX-minted-auto-newminted nil)
 (defvar LaTeX-minted-newminted-regexp
   '("\\\\newminted\\(?:\\[\\([^]]+\\)\\]\\)?{\\([^}]+\\)}{[^}]*}"
@@ -256,24 +253,24 @@ are loaded."
 
 (defun LaTeX-minted-auto-prepare ()
   (setq LaTeX-minted-auto-newminted     nil
-	LaTeX-minted-auto-newmint       nil
-	LaTeX-minted-auto-newmintinline nil
-	LaTeX-minted-auto-newmintedfile nil
-	LaTeX-minted-language-list      nil
-	LaTeX-minted-style-list         nil))
+        LaTeX-minted-auto-newmint       nil
+        LaTeX-minted-auto-newmintinline nil
+        LaTeX-minted-auto-newmintedfile nil
+        LaTeX-minted-language-list      nil
+        LaTeX-minted-style-list         nil))
 
 (defun LaTeX-minted-auto-cleanup ()
   ;; \newminted{lang}{opts} => new langcode and langcode* envs.
   ;; \newminted[envname]{lang}{opts} => new envname/envname* envs.
   (dolist (name-lang LaTeX-minted-auto-newminted)
     (let* ((env (if (> (length (car name-lang)) 0)
-		    (car name-lang)
-		  (concat (cadr name-lang) "code")))
-	   (env* (concat env "*")))
+                    (car name-lang)
+                  (concat (cadr name-lang) "code")))
+           (env* (concat env "*")))
       (add-to-list 'LaTeX-auto-environment (list env))
       (add-to-list 'LaTeX-auto-environment
-		   (list env* 'LaTeX-env-args
-			 '(TeX-arg-key-val LaTeX-minted-key-val-options-local)))
+                   (list env* #'LaTeX-env-args
+                         '(TeX-arg-key-val (LaTeX-minted-key-val-options))))
       (add-to-list 'LaTeX-indent-environment-list `(,env current-indentation) t)
       (add-to-list 'LaTeX-indent-environment-list `(,env* current-indentation) t)
       (add-to-list 'LaTeX-verbatim-environments-local env)
@@ -282,48 +279,44 @@ are loaded."
   ;; \newmint[macname]{foo}{opts} => \macname[key=vals]|code|
   (dolist (name-lang LaTeX-minted-auto-newmint)
     (let ((lang (if (> (length (car name-lang)) 0)
-		    (car name-lang)
-		  (cadr name-lang))))
+                    (car name-lang)
+                  (cadr name-lang))))
       (add-to-list 'TeX-auto-symbol
-		   `(,lang [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-			   TeX-arg-verb))
+                   `(,lang [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+                           TeX-arg-verb))
       (add-to-list 'LaTeX-verbatim-macros-with-delims-local lang)
       (when (and (fboundp 'font-latex-add-keywords)
-		 (fboundp 'font-latex-update-font-lock)
-		 (eq TeX-install-font-lock 'font-latex-setup))
-	(font-latex-add-keywords `((,lang "[")) 'textual))))
+                 (eq TeX-install-font-lock 'font-latex-setup))
+        (font-latex-add-keywords `((,lang "[")) 'textual))))
   ;; \newmintinline{foo}{opts} => \fooinline[key=vals]|code| or
   ;;                              \fooinline[key=vals]{code}
   ;; \newmintinline[macname]{foo}{opts} => \macname[key=vals]|code| or
   ;;                                       \macname[key=vals]{code}
   (dolist (name-lang LaTeX-minted-auto-newmintinline)
     (let ((lang (if (> (length (car name-lang)) 0)
-		    (car name-lang)
-		  (concat (cadr name-lang) "inline"))))
+                    (car name-lang)
+                  (concat (cadr name-lang) "inline"))))
       (add-to-list 'TeX-auto-symbol
-		   `(,lang [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-			  TeX-arg-verb-delim-or-brace))
+                   `(,lang [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+                           TeX-arg-verb-delim-or-brace))
       (add-to-list 'LaTeX-verbatim-macros-with-delims-local lang)
       (add-to-list 'LaTeX-verbatim-macros-with-braces-local lang)
       (when (and (fboundp 'font-latex-add-keywords)
-		 (fboundp 'font-latex-update-font-lock)
-		 (eq TeX-install-font-lock 'font-latex-setup))
-	(font-latex-add-keywords `((,lang "[")) 'textual))))
+                 (eq TeX-install-font-lock 'font-latex-setup))
+        (font-latex-add-keywords `((,lang "[")) 'textual))))
   ;; \newmintedfile{foo}{opts} => \foofile[key=vals]{file-name}
   ;; \newmintedfile[macname]{foo}{opts} => \macname[key=vals]{file-name}
   (dolist (name-lang LaTeX-minted-auto-newmintedfile)
     (let ((lang (if (> (length (car name-lang)) 0)
-		    (car name-lang)
-		  (concat (cadr name-lang) "file"))))
+                    (car name-lang)
+                  (concat (cadr name-lang) "file"))))
       (add-to-list 'TeX-auto-symbol
-		   `(,lang [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
-			   TeX-arg-file))))
-  (when (and (fboundp 'font-latex-update-font-lock)
-	     (eq TeX-install-font-lock 'font-latex-setup))
+                   `(,lang [TeX-arg-key-val (LaTeX-minted-key-val-options)]
+                           TeX-arg-file))))
+  (when (and (fboundp 'font-latex-set-syntactic-keywords)
+             (eq TeX-install-font-lock 'font-latex-setup))
     ;; Refresh font-locking so that the verbatim envs take effect.
-    (font-latex-update-font-lock t))
-  ;; Also update the key=vals
-  (LaTeX-minted-update-key-vals))
+    (font-latex-set-syntactic-keywords)))
 
 (add-hook 'TeX-auto-prepare-hook #'LaTeX-minted-auto-prepare t)
 (add-hook 'TeX-auto-cleanup-hook #'LaTeX-minted-auto-cleanup t)
@@ -335,67 +328,63 @@ TYPE is one of the symbols `brace' or `delim' indicating how
 verbatim text is enclosed after the macro.  MACRO is a string or
 a list of strings."
   (let ((syntax (if (eq type 'brace)
-		    '((1 "|") (2 "|"))
-		  '((1 "\"") (2 ".") (3 "\""))))
-	regexp)
+                    '((1 "|") (2 "|"))
+                  '((1 "\"") (2 ".") (3 "\""))))
+        regexp)
     (when (listp macro)
       (setq macro (regexp-opt macro "\\(?:")))
     (setq regexp `(,(concat
-		     ;; The backslash
-		     (regexp-quote TeX-esc)
-		     ;; Name of the macro(s)
-		     macro
-		     ;; The optional argument
-		     "\\(?:\\[[^][]*\\(?:\\[[^][]*\\][^][]*\\)*\\]\\)?"
-		     ;; The first mandatory argument
-		     "\\(?:{[^}]+}\\)"
-		     ;; With 'brace, allow braced sub-groups otherwise
-		     ;; we stop matching too early.  With 'delim, copy
-		     ;; font-latex.el:
-		     (if (eq type 'brace)
-			 (concat "\\({\\)"
-				   "\\(?:[^}{]*"
-				     "\\(?:{[^}{]*"
-				       "\\(?:{[^}{]*"
-					 "\\(?:{[^}{]*}[^}{]*\\)*"
-				       "}[^}{]*\\)*"
-				     "}[^}{]*\\)*"
-				   "\\)"
-				 "\\(}\\)")
-		       (concat
-			;; Opening delimiter
-			"\\([^a-z@*\n\f{]\\).*?"
-			;; Closing delimiter
-			"\\(" (regexp-quote TeX-esc) "*\\)\\(\\1\\)")))))
+                     ;; The backslash
+                     (regexp-quote TeX-esc)
+                     ;; Name of the macro(s)
+                     macro
+                     ;; The optional argument
+                     "\\(?:\\[[^][]*\\(?:\\[[^][]*\\][^][]*\\)*\\]\\)?"
+                     ;; The first mandatory argument
+                     "\\(?:{[^}]+}\\)"
+                     ;; With 'brace, allow braced sub-groups otherwise
+                     ;; we stop matching too early.  With 'delim, copy
+                     ;; font-latex.el:
+                     (if (eq type 'brace)
+                         (concat "\\({\\)"
+                                   "\\(?:[^}{]*"
+                                     "\\(?:{[^}{]*"
+                                       "\\(?:{[^}{]*"
+                                         "\\(?:{[^}{]*}[^}{]*\\)*"
+                                       "}[^}{]*\\)*"
+                                     "}[^}{]*\\)*"
+                                   "\\)"
+                                 "\\(}\\)")
+                       (concat
+                        ;; Opening delimiter
+                        "\\([^a-z@*\n\f{]\\).*?"
+                        ;; Closing delimiter
+                        "\\(" (regexp-quote TeX-esc) "*\\)\\(\\1\\)")))))
     (add-to-list 'font-latex-syntactic-keywords-extra (append regexp syntax))))
 
 (TeX-add-style-hook
  "minted"
  (lambda ()
 
-   ;; Activate local-version of key=vals
-   (setq LaTeX-minted-key-val-options-local
-	 (copy-alist LaTeX-minted-key-val-options))
-
    ;; New symbols
    (TeX-add-symbols
     '("mint"
-      [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
       LaTeX-arg-minted-language TeX-arg-verb)
     '("mintinline"
-      [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
       LaTeX-arg-minted-language TeX-arg-verb-delim-or-brace)
     '("newminted" ["Environment Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     '("newmint" ["Macro Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     '("newmintinline" ["Macro Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     '("newmintedfile" ["Macro Name"] LaTeX-arg-minted-language
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     ;; 3.3 Formatting source code
     '("inputminted"
-      [ TeX-arg-key-val LaTeX-minted-key-val-options-local ]
+      [TeX-arg-key-val (LaTeX-minted-key-val-options)]
       (LaTeX-arg-minted-language)
       TeX-arg-file)
     ;; 3.4 Using different styles
@@ -404,35 +393,35 @@ a list of strings."
     ;; 5.2 Macro option usage
     '("setminted"
       [ LaTeX-arg-minted-language ]
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local))
+      (TeX-arg-key-val (LaTeX-minted-key-val-options)))
     '("setmintedinline"
       [ LaTeX-arg-minted-language ]
-      (TeX-arg-key-val LaTeX-minted-key-val-options-local)))
+      (TeX-arg-key-val (LaTeX-minted-key-val-options))))
 
    ;; New environments
    (LaTeX-add-environments
-    '("minted" LaTeX-env-args [TeX-arg-key-val LaTeX-minted-key-val-options-local]
+    '("minted" LaTeX-env-args [TeX-arg-key-val (LaTeX-minted-key-val-options)]
       LaTeX-arg-minted-language))
 
    ;; 4 Floating listings: If option "newfloat" is given, run the
    ;; style hook and use the interface provided by the style,
    ;; otherwise add "listing" manually
    (if (or (LaTeX-provided-package-options-member "minted" "newfloat")
-	   (LaTeX-provided-package-options-member "minted" "newfloat=true"))
+           (LaTeX-provided-package-options-member "minted" "newfloat=true"))
        (progn
-	 (TeX-run-style-hooks "newfloat")
-	 (LaTeX-add-newfloat-DeclareFloatingEnvironments
-	  '("listing" "verbatim")))
+         (TeX-run-style-hooks "newfloat")
+         (LaTeX-add-newfloat-DeclareFloatingEnvironments
+          '("listing" "verbatim")))
      (LaTeX-add-environments '("listing" ["Float Position"]))
      (TeX-add-symbols '("listoflistings")
-		      '("listingscaption")
-		      '("listoflistingscaption"))
+                      '("listingscaption")
+                      '("listoflistingscaption"))
      (add-to-list (make-local-variable 'LaTeX-indent-environment-list)
-		  '("listing" current-indentation) t)
+                  '("listing" current-indentation) t)
      (add-to-list 'LaTeX-label-alist '("listing" . LaTeX-listing-label) t)
      (when (fboundp 'reftex-add-label-environments)
        (reftex-add-label-environments
-	'(("listing" ?l "lst:" "~\\ref{%s}" caption nil nil)))))
+        '(("listing" ?l "lst:" "~\\ref{%s}" caption nil nil)))))
 
    ;; Add to the auto parser
    (TeX-auto-add-regexp LaTeX-minted-newminted-regexp)
@@ -442,43 +431,42 @@ a list of strings."
 
    ;; Filling
    (add-to-list (make-local-variable 'LaTeX-indent-environment-list)
-		'("minted" current-indentation) t)
+                '("minted" current-indentation) t)
    (add-to-list 'LaTeX-verbatim-environments-local "minted")
 
    ;; Fontification
    (when (and (fboundp 'font-latex-add-keywords)
-	      (fboundp 'font-latex-update-font-lock)
-	      (eq TeX-install-font-lock 'font-latex-setup))
+              (eq TeX-install-font-lock 'font-latex-setup))
      (font-latex-add-keywords '(("usemintedstyle"  "[{")
-				("setminted"       "[{")
-				("setmintedinline" "[{")
-				("newminted"       "[{{")
-				("newmint"         "[{{")
-				("newmintinline"   "[{{")
-				("newmintedfile"   "[{{"))
-			      'function)
+                                ("setminted"       "[{")
+                                ("setmintedinline" "[{")
+                                ("newminted"       "[{{")
+                                ("newmint"         "[{{")
+                                ("newmintinline"   "[{{")
+                                ("newmintedfile"   "[{{"))
+                              'function)
      (font-latex-add-keywords '(("inputminted" "[{{")
-				("mint"        "[{")
-				("mintinline"  "[{"))
-			      'textual)
+                                ("mint"        "[{")
+                                ("mintinline"  "[{"))
+                              'textual)
      ;; Add \mint & \mintinline to
      ;; `font-latex-syntactic-keywords-extra' and cater for their
      ;; special syntax: \mint[optional]{lang}{verbatim} or
      ;;                 \mint[optional]{lang}|verbatim|
      (LaTeX-minted-add-syntactic-keywords-extra 'brace
-						'("mint" "mintinline"))
+                                                '("mint" "mintinline"))
      (LaTeX-minted-add-syntactic-keywords-extra 'delim
-						'("mint" "mintinline"))
+                                                '("mint" "mintinline"))
      ;; Tell font-lock about the update.
-     (font-latex-update-font-lock t)))
- LaTeX-dialect)
+     (font-latex-set-syntactic-keywords)))
+ TeX-dialect)
 
 (defvar LaTeX-minted-package-options '("chapter"     "cache"
-				       "cachedir"    "finalizecache"
-				       "frozencache" "draft"
-				       "final"       "kpsewhich"
-				       "langlinenos" "newfloat"
-				       "outputdir"   "section")
+                                       "cachedir"    "finalizecache"
+                                       "frozencache" "draft"
+                                       "final"       "kpsewhich"
+                                       "langlinenos" "newfloat"
+                                       "outputdir"   "section")
   "Package options for the minted package.")
 
 ;;; minted.el ends here
