@@ -1,6 +1,6 @@
-;;; shortvrb.el --- AUCTeX style for `shortvrb.sty'
+;;; shortvrb.el --- AUCTeX style for `shortvrb.sty'  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2009, 2014, 2018 Free Software Foundation, Inc.
+;; Copyright (C) 2009, 2014, 2018, 2020 Free Software Foundation, Inc.
 
 ;; Author: Ralf Angeli <angeli@caeruleus.net>
 ;; Maintainer: auctex-devel@gnu.org
@@ -41,48 +41,33 @@
 
 ;;; Code:
 
+(require 'tex)
+(require 'tex-style)
+
 ;; Silence the compiler:
 (declare-function font-latex-add-to-syntax-alist
-		  "font-latex"
-		  (list))
-
-(defcustom LaTeX-shortvrb-chars nil
-  "List of characters toggling verbatim mode.
-When your document uses the shortvrb style and you have a
-\\MakeShortVrb{\\|} in your file to write verbatim text as
-|text|, then set this variable to the list (?|).  Then AUCTeX
-fontifies |text| as verbatim.
-
-Preferably, you should do this buffer-locally using a file
-variable near the end of your document like so:
-
-  %% Local Variables:
-  %% LaTeX-shortvrb-chars: (?|)
-  %% End:
-
-When you customize this variable to a non-nil value, then it
-becomes the default value meaning that verbatim fontification is
-always performed for the characters in the list, no matter if
-your document actually defines shortvrb chars using
-\\MakeShortVrb."
-  :group 'LaTeX-style
-  :type '(repeat character))
-(put 'LaTeX-shortvrb-chars 'safe-local-variable 'listp)
+                  "font-latex"
+                  (list))
 
 (TeX-add-style-hook
  "shortvrb"
  (lambda ()
+
+   ;; Ispell: Add entries to `ispell-tex-skip-alist':
+   (when LaTeX-shortvrb-chars
+     (TeX-ispell-skip-setcar
+      (mapcar (lambda (char)
+                (let ((str (char-to-string char)))
+                  (cons str str)))
+              LaTeX-shortvrb-chars)))
+
    ;; Fontification
    (when (and LaTeX-shortvrb-chars
-	      (fboundp 'font-latex-set-syntactic-keywords)
-	      (eq TeX-install-font-lock 'font-latex-setup))
+              (featurep 'font-latex)
+              (eq TeX-install-font-lock 'font-latex-setup))
      (font-latex-add-to-syntax-alist
       (mapcar (lambda (char) (cons char "|"))
               LaTeX-shortvrb-chars))))
- LaTeX-dialect)
-
-;; Don't look for file-local variables before this line, so that the example in
-;; the docstring isn't picked up.
-
+ TeX-dialect)
 
 ;;; shortvrb.el ends here
