@@ -1,6 +1,6 @@
-;;; xspace.el --- AUCTeX style for `xspace.sty'
+;;; xspace.el --- AUCTeX style for `xspace.sty'  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2011, 2018 Free Software Foundation, Inc.
+;; Copyright (C) 2011, 2018, 2020 Free Software Foundation, Inc.
 
 ;; Author: Mads Jensen <mje@inducks.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -30,10 +30,12 @@
 
 ;;; Code:
 
+(require 'tex)
+
 ;; Silence the compiler:
 (declare-function font-latex-add-keywords
-		  "font-latex"
-		  (keywords class))
+                  "font-latex"
+                  (keywords class))
 
 (TeX-add-style-hook
  "xspace"
@@ -45,12 +47,12 @@
 
    ;; Fontification
    (when (and (featurep 'font-latex)
-	      (eq TeX-install-font-lock 'font-latex-setup))
+              (eq TeX-install-font-lock 'font-latex-setup))
      (font-latex-add-keywords '(("xspace" "")
-				("xspaceaddexception" "{")
-				("xspaceremoveexception" "{"))
-			      'function)))
- LaTeX-dialect)
+                                ("xspaceaddexception" "{")
+                                ("xspaceremoveexception" "{"))
+                              'function)))
+ TeX-dialect)
 
 (defvar LaTeX-xspace-package-options nil
   "Package options for the xspace package.")
